@@ -16,7 +16,7 @@ def assert_window_almost_equals(a, b, precision=3):
     assert round(a.height, precision) == round(b.height, precision)
 
 
-class MockDatasetBase(object):
+class MockDatasetBase:
     def __init__(self):
         # from tests/data/RGB.byte.tif
         self.affine = Affine(300.0379266750948, 0.0, 101985.0,
